==> mgb-0.5.3-de.zip: mgb-0.5.3-de/language/lang_main.php <==
<?php
         // MGB v.null.fnf (C) by Jrgen Grneisl
         //
         // This Guestbook is licensed under GNU GPL. Feel free to use, copy, share or modify it. :)
         //
         // released on 27th of October 2005

//lang_main.php - Sprachvariablen fr das Gstebuch

	//////////////////
	// DEUTSCH v1.0 //
	//////////////////

// Allgemeine Variablen

$lang['back_to_gb']	= "Zurck zum Gstebuch";

$lang['failuremessage1']	= "Bitte geben Sie eine Nachricht ein!";
$lang['failuremessage2']	= "Bitte geben Sie eine gltige eMail Adresse ein!";
$lang['failuremessage3']	= "Bitte geben Sie einen Namen ein!";
$lang['failuremessage4']	= "ist keine gltige<br>ICQ Nummer!";
$lang['failuremessage5']	= "ist keine gltige<br>eMail Adresse!";
$lang['failuremessage6']	= "Bitte geben Sie einen Betreff ein!";

$lang['forwarding']	= "Du wirst in 5 Sekunden automatisch weitergeleitet. Wenn nicht klicke bitte hier.";


// guestbook.php = Hauptseite / Main page

// Wenn eine Variable den Zusatz "before" oder "after" beinhaltet, bedeutet
// das, da dieser Teil vor oder nach der Variable steht, deren Bezeichnung
// ganz am Schlu innerhalb dieser Variable steht.

$lang['new_entry']	= "Eintragen";
$lang['contact']		= "Kontakt";
$lang['administration']	= "Administration";

$lang['entry']		= "Eintrag";
$lang['entrys']		= "Eintrge";
$lang['no_entrys']	= "Es wurden leider noch keine<br>Eintr&auml;ge hinterlassen.";

$lang['from']				= "aus";
$lang['between_date_and_time']		= "um";
$lang['time']				= "Uhr";
$lang['comment']				= "Kommentar";
$lang['alt_email_spam_on_before_name']	= "";
$lang['alt_email_spam_on_after_name']	= "eine eMail schreiben";
$lang['alt_email_before_name']		= "eMail von";
$lang['alt_email_after_name']		= "";
$lang['alt_homepage_before_name']	= "Homepage von";
$lang['alt_homepage_after_name']		= "";
$lang['entrys_on_pages_before_counter']	= "Eintrge auf";
$lang['entrys_on_pages_after_counter']	= "Seiten";


// eintragen.php = Seite um einen neuen Eintrag zu machen / Page for a new entry

$lang['title_message_new_entry']	= "Neuer Eintrag";

$lang['name']			= "Dein Name:";
$lang['city']			= "Wohnort:";
$lang['eMail']			= "eMail:";
$lang['icq']			= "ICQ:";
$lang['aim']			= "AIM:";
$lang['msn']			= "MSN:";
$lang['homepage']		= "Homepage:";
$lang['message']			= "Deine Nachricht:";
$lang['notify']			= "Benachrichtige mich, wenn mein Beitrag freigeschalten, oder ein Kommentar dazu geschrieben wurde";
$lang['mandatory']		= "Pflichtfelder sind mit einem Stern (*) gekennzeichnet";
$lang['quakecodes_before_link']	= "Dieses Gstebuch untersttzt ";
$lang['quakecodes_link']		= "Quake Farbcodes";
$lang['quakecodes_after_link']	= "";
$lang['send']			= "Eintragen";

$lang['entry_successful']	= "Dein Eintrag wurde erfolgreich gespeichert. Er wird vom Admin begutachtet, und dann freigeschaltet werden.";
$lang['entry_not_successful']	= "Es ist ein Problem aufgetreten. Der Eintrag konnte nicht gespeichert werden!";


// email.php = eMail bei Spamschutz an einen Benutzer schicken / Send an eMail to a user when spamprotection is on

$lang['subject']					= "Betreff:";
$lang['all_fields_mandatory']			= "Alle Felder mssen ausgefllt werden";
$lang['send_email']				= "Abschicken";
$lang['email_sent']				= "Deine eMail wurde erfolgreich an den Benutzer verschickt.";
$lang['title_message_send_email_before_name']    = "Email an";
$lang['send_email_to_admin']                     = "den Admin";
$lang['title_message_send_email_after_name']     = "schreiben";


// eMails

// Neuer Eintrag / new entry
$lang['email_to_admin_new_entry_subject']	= "Neuer Eintrag von"." ";
$lang['email_to_admin_new_entry_message']	= " "."hat sich ins Gstebuch auf ".$settings['hpname']." eingetragen.";	// ".$settings['hpname']." includes the name of your homepage
$lang['email_to_user_new_entry_subject']		= "Vielen Dank";
$lang['email_to_user_new_entry_greeting']	= "Hallo"." ";
$lang['email_to_user_new_entry_message']		= "Vielen Dank, da Sie sich in mein Gstebuch eingetragen haben. Ihr Eintrag wird nach einer berprfung freigeschalten. Ich wrde mich auf weitere Besuche von Ihnen freuen.\n\nHier knnen Sie sich Ihren Eintrag ansehen, nachdem er freigeschaltet wurde:"." ";	// \n forces a linebreak in eMail

// Email ber das Gstebuch / email over guestbook
$lang['email_sender']	= "Absender";
$lang['email_from']	= "Gesendet ber das Gstebuch von"; // Name wird automatisch hinzugefgt

// Gstebuchinformationen / guestbookinfo
$lang['active']		= "aktiv";
$lang['inactive']	= "inaktiv";
$lang['spamprotection']	= "eMail Spamschutz";
$lang['smilies']		= "Smilies";
$lang['censorship']	= "Wortzensur";
$lang['quakemessage']	= "Farbencodes fr Nachrichten";


// Smilies

$lang['smilie_smile']	= "lcheln";
$lang['smilie_biggrin']	= "grosses Grinsen";
$lang['smilie_lol']	= "lautes Lachen";
$lang['smilie_wink']	= "zwinkern";
$lang['smilie_surprised']= "berrascht";
$lang['smilie_tongue']	= "Zunge zeigend";
$lang['smilie_cool']	= "cool";
$lang['smilie_eek']	= "Aaaahhh";
$lang['smilie_confused']	= "verwirrt";
$lang['smilie_sad']	= "traurig";
$lang['smilie_angry']	= "verrgert";


?>

==> mgb-0.5.4.3-de.zip: mgb-0.5.4.3-de/language/lang_main.php <==
<?php
	/*
	MGB 0.5.4.3
	Copyright (C) 2004 - 2006  Juergen Grueneisl

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	*/

//lang_main.php - Sprachvariablen fr das Gstebuch

////////////////////
// DEUTSCH v1.0.2 //
////////////////////

// Allgemeine Variablen

$lang['back_to_gb']	= "Zurck zum Gstebuch";

$lang['failuremessage1']	= "Bitte geben Sie eine Nachricht ein!";
$lang['failuremessage2']	= "Bitte geben Sie eine gltige eMail Adresse ein!";
$lang['failuremessage3']	= "Bitte geben Sie einen Namen ein!";
$lang['failuremessage4']	= "ist keine gltige<br>ICQ Nummer!";
$lang['failuremessage5']	= "ist keine gltige<br>eMail Adresse!";
$lang['failuremessage6']	= "Bitte geben Sie einen Betreff ein!";
$lang['failuremessage7']	= "Die IP Sperre verbietet einen weiteren Eintrag!";
$lang['failuremessage8']	= "Der Sicherheitscode wurde falsch eingegeben!";

$lang['forwarding']	= "Du wirst in 5 Sekunden automatisch weitergeleitet. Wenn nicht klicke bitte hier.";


// guestbook.php = Hauptseite / Main page

// Wenn eine Variable den Zusatz "before" oder "after" beinhaltet, bedeutet
// das, da dieser Teil vor oder nach der Variable steht, deren Bezeichnung
// ganz am Schlu innerhalb dieser Variable steht.

$lang['new_entry']	= "Eintragen";
$lang['contact']		= "Kontakt";
$lang['administration']	= "Administration";

$lang['entry']		= "Eintrag";
$lang['entrys']		= "Eintrge";
$lang['no_entrys']	= "Es wurden leider noch keine<br>Eintr&auml;ge hinterlassen.";

$lang['from']				= "aus";
$lang['between_date_and_time']		= "um";
$lang['time']				= "Uhr";
$lang['comment']				= "Kommentar";
$lang['alt_email_spam_on_before_name']	= "";
$lang['alt_email_spam_on_after_name']	= "eine eMail schreiben";
$lang['alt_email_before_name']		= "eMail von";
$lang['alt_email_after_name']		= "";
$lang['alt_homepage_before_name']	= "Homepage von";
$lang['alt_homepage_after_name']		= "";
$lang['entrys_on_pages_before_counter']	= "Eintrge auf";
$lang['entrys_on_pages_after_counter']	= "Seiten";


// eintragen.php = Seite um einen neuen Eintrag zu machen / Page for a new entry

$lang['title_message_new_entry']	= "Neuer Eintrag";

$lang['name']			= "Dein Name:";
$lang['city']			= "Wohnort:";
$lang['eMail']			= "eMail:";
$lang['icq']			= "ICQ:";
$lang['aim']			= "AIM:";
$lang['msn']			= "MSN:";
$lang['homepage']		= "Homepage:";
$lang['message']			= "Deine Nachricht:";
$lang['captcha']			= "Sicherheitscode:";
$lang['bbcodes']			= "<b>BBCodes</b> sind aktiviert";
$lang['notify']			= "Benachrichtige mich, wenn mein Beitrag freigeschalten, oder ein Kommentar dazu geschrieben wurde";
$lang['mandatory']		= "Pflichtfelder sind mit einem Stern (*) gekennzeichnet";
$lang['quakecodes_before_link']	= "Dieses Gstebuch untersttzt ";
$lang['quakecodes_link']		= "Quake Farbcodes";
$lang['quakecodes_after_link']	= "";
$lang['send']			= "Eintragen";

$lang['entry_successful_moderated']	= "Dein Eintrag wurde erfolgreich gespeichert. Er wird vom Admin begutachtet, und dann freigeschaltet werden.";
$lang['entry_successful_not_moderated']	= "Dein Eintrag wurde erfolgreich gespeichert. Du kannst ihn Dir sofort ansehen.";
$lang['entry_not_successful']		= "Es ist ein Problem aufgetreten. Der Eintrag konnte nicht gespeichert werden!";


// email.php = eMail bei Spamschutz an einen Benutzer schicken / Send an eMail to a user when spamprotection is on

$lang['subject']					= "Betreff:";
$lang['all_fields_mandatory']			= "Alle Felder mssen ausgefllt werden";
$lang['send_email']				= "Abschicken";
$lang['email_sent']				= "Deine eMail wurde erfolgreich an den Benutzer verschickt.";
$lang['title_message_send_email_before_name']    = "Email an";
$lang['send_email_to_admin']                     = "den Admin";
$lang['title_message_send_email_after_name']     = "schreiben";


// eMails

// Neuer Eintrag / new entry
$lang['email_to_admin_new_entry_subject']		= "Neuer Eintrag von"." ";
$lang['email_to_admin_new_entry_message']		= " "."hat sich ins Gstebuch auf ".$settings['hpname']." eingetragen.";	// ".$settings['hpname']." includes the name of your homepage
$lang['email_to_user_new_entry_subject']			= "Vielen Dank";
$lang['email_to_user_new_entry_greeting']		= "Hallo"." ";
$lang['email_to_user_new_entry_message_moderated']	= "Vielen Dank, da Sie sich in mein Gstebuch eingetragen haben. Ihr Eintrag wird nach einer berprfung freigeschalten. Ich wrde mich auf weitere Besuche von Ihnen freuen.\n\nHier knnen Sie sich Ihren Eintrag ansehen, nachdem er freigeschaltet wurde:"." ";	// \n forces a linebreak in eMail
$lang['email_to_user_new_entry_message_not_moderated']	= "Vielen Dank, da Sie sich in mein Gstebuch eingetragen haben. Ich wrde mich auf weitere Besuche von Ihnen freuen.\n\nHier knnen Sie sich Ihren Eintrag ansehen:"." ";	// \n forces a linebreak in eMail

// Email ber das Gstebuch / email over guestbook
$lang['email_sender']	= "Absender";
$lang['email_from']	= "Gesendet ber das Gstebuch von"; // Name wird automatisch hinzugefgt

// Gstebuchinformationen / guestbookinfo
$lang['active']		= "aktiv";
$lang['inactive']	= "inaktiv";
$lang['spamprotection']	= "eMail Spamschutz";
$lang['smilies']		= "Smilies";
$lang['bbcode']		= "BBCode";
$lang['censorship']	= "Wortzensur";
$lang['quakemessage']	= "Farbencodes fr Nachrichten";


// Smilies

$lang['smilie_smile']	= "lcheln";
$lang['smilie_biggrin']	= "grosses Grinsen";
$lang['smilie_lol']	= "lautes Lachen";
$lang['smilie_wink']	= "zwinkern";
$lang['smilie_surprised']= "berrascht";
$lang['smilie_tongue']	= "Zunge zeigend";
$lang['smilie_cool']	= "cool";
$lang['smilie_eek']	= "Aaaahhh";
$lang['smilie_confused']	= "verwirrt";
$lang['smilie_sad']	= "traurig";
$lang['smilie_angry']	= "verrgert";


?>
